@@ -21,51 +21,33 @@
 
 #include <config.h>
 
-#include <stdlib.h>
 #include <osinfo/osinfo.h>
-#include <check.h>
 
 
 
-START_TEST(test_basic)
+static void
+test_basic(void)
 {
     OsinfoDevice *device = osinfo_device_new("e1000");
 
-    fail_unless(OSINFO_IS_DEVICE(device), "Device is a device object");
-    fail_unless(g_strcmp0(osinfo_entity_get_id(OSINFO_ENTITY(device)), "e1000") == 0, "Device ID was e1000");
+    g_assert_true(OSINFO_IS_DEVICE(device));
+    g_assert_cmpstr(osinfo_entity_get_id(OSINFO_ENTITY(device)), ==, "e1000");
 
     g_object_unref(device);
 }
-END_TEST
 
 
-static Suite *
-device_suite(void)
+int
+main(int argc, char *argv[])
 {
-    Suite *s = suite_create("Device");
-    TCase *tc = tcase_create("Core");
-    tcase_add_test(tc, test_basic);
-    suite_add_tcase(s, tc);
-    return s;
-}
+    g_test_init(&argc, &argv, NULL);
 
-int main(void)
-{
-    int number_failed;
-    Suite *s = device_suite();
-    SRunner *sr = srunner_create(s);
-
-    /* Make sure we catch unexpected g_warning() */
-    g_log_set_always_fatal(G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
+    g_test_add_func("/device/basic", test_basic);
 
     /* Upfront so we don't confuse valgrind */
     osinfo_device_get_type();
 
-    srunner_run_all(sr, CK_ENV);
-    number_failed = srunner_ntests_failed(sr);
-    srunner_free(sr);
-
-    return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
+    return g_test_run();
 }
 /*
  * Local variables:
